@@ -12,7 +12,8 @@
 
 globalVariables(c("pems.scheme", "ref.unit.conversions", "ref.chem", "ref.diesel", "ref.petrol",
                   "panel.surfaceSmooth", "data", "exh.flow.rate", "exh.press", "exh.temp", 
-                  "local.time"))
+                  "local.time", "pems_speedEm2", "add", "grp",
+                  "temp"))
 
 #might move following into function
 #      exh.flow.rate exh.press exh.temp local.time
